@@ -51,11 +51,10 @@ class Keeper(object):
         42: 'Kovan',
         77: 'POA_Sokol',
         99: 'POA_Core',
-        8995: 'nile',
+        137: 'matic',
         8996: 'spree',
         8997: 'polygon-localnet',
-        2199: 'duero',
-        0xcea11: 'pacific',
+        42220: 'celo',
         44787: 'celo-alfajores',
         62320: 'celo-baklava',
         80001: 'mumbai',
